==> sat_datetime-0.4.tar.gz: sat_datetime-0.4/setup.py <==
from distutils.core import setup

setup(
    name='sat_datetime',  # How you named your package folder (MyLib)
    packages=['sat_datetime'],  # Chose the same as "name"
    version='0.4',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='Sat universe time calculation',  # Give a short description about your library
    author='Sch Jeon',  # Type in your name
    author_email='junhg0211@gmail.com',  # Type in your E-Mail
    url='https://github.com/junhg0211/sat-datetime',  # Provide either the link to your github or to your website
    download_url='https://github.com/junhg0211/sat-datetime/archive/refs/tags/v_0.4.tar.gz',  # I explain this later on
    keywords=['sat', 'datetime'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'validators',
        'beautifulsoup4',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3.7',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)

==> sat_datetime-1.0.tar.gz: sat_datetime-1.0/setup.py <==
from distutils.core import setup

setup(
    name='sat_datetime',  # How you named your package folder (MyLib)
    packages=['sat_datetime'],  # Chose the same as "name"
    version='1.0',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='Sat universe time calculation',  # Give a short description about your library
    author='Sch Jeon',  # Type in your name
    author_email='junhg0211@gmail.com',  # Type in your E-Mail
    url='https://github.com/junhg0211/sat-datetime',  # Provide either the link to your github or to your website
    download_url='https://github.com/Zeli-B/sat-datetime/archive/refs/tags/v_1.0.tar.gz',  # I explain this later on
    keywords=['sat', 'datetime'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'validators',
        'beautifulsoup4',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3.7',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
